@@ -1,14 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Python module: Client ModBus / TCP class 1
-#       Version: 0.0.6
-#       Website: https://github.com/sourceperl/pyModbusTCP
-#          Date: 2014-08-25
-#       License: MIT (http://http://opensource.org/licenses/mit-license.php)
-#   Description: Client ModBus / TCP
-#                Support functions 3 and 16 (class 0)
-#                1,2,4,5,6 (Class 1)
-#       Charset: utf-8
+# Python module: ModbusClient class (Client ModBus/TCP class 1)
 
 from pyModbusTCP import constants as const
 import re
@@ -20,7 +12,7 @@ import random
 class ModbusClient:
     """Client Modbus TCP"""
 
-    def __init__(self, host=None, port=None, debug=None):
+    def __init__(self, host=None, port=None, unit_id=None, debug=None):
         """Constructor
 
         Modbus server params (host, port) can be set here or with host(), port()
@@ -32,11 +24,13 @@ class ModbusClient:
         :type host: str
         :param port: TCP port number (optional)
         :type port: int
+        :param unit_id: unit ID (optional)
+        :type unit_id: int
         :param debug: debug state (optional)
         :type debug: bool
         :return: Object ModbusClient
         :rtype: ModbusClient
-        :raises ValueError: host, port or debug value is set but incorrect
+        :raises ValueError: if a set parameter value is incorrect
         """
         # object vars
         self.__hostname    = "localhost"
@@ -58,7 +52,11 @@ class ModbusClient:
         if port:
             if not self.port(port):
                 raise ValueError("port value error")
-        # set hostname
+        # set unit_id
+        if unit_id:
+            if not self.unit_id(unit_id):
+                raise ValueError("unit_id value error")
+        # set debug
         if debug:
             if not self.debug(debug):
                 raise ValueError("debug value error")
